>From 946657e013de5e77bac6d1ef227fc6b101eb694b Mon Sep 17 00:00:00 2001
From: Roiy Shpaner <roiy@cs.umanitoba.ca>
Date: Fri, 4 Apr 2014 12:22:52 -0500
Subject: [PATCH 10/10] MED Support - Settings

---
 modules/gui/qt4/menus.cpp | 41 +++++++++++++++++++++++++++++++++++++++++
 modules/gui/qt4/menus.hpp |  1 +
 src/libvlc-module.c       | 13 +++++++++++++
 3 files changed, 55 insertions(+)

diff --git a/modules/gui/qt4/menus.cpp b/modules/gui/qt4/menus.cpp
index 7c25c04..7cb6ed7 100644
--- a/modules/gui/qt4/menus.cpp
+++ b/modules/gui/qt4/menus.cpp
@@ -516,6 +516,9 @@ QMenu *VLCMenuBar::ViewMenu( intf_thread_t *p_intf, QMenu *current, MainInterfac
     CONNECT( mi, fullscreenInterfaceToggled( bool ),
              action, setChecked( bool ) );
 
+    /* Media Enhancement Data interface options */
+    MedMenu( p_intf, mi, menu );
+
     /* Advanced Controls */
     action = menu->addAction( qtr( "&Advanced Controls" ), mi,
             SLOT( toggleAdvancedButtons() ) );
@@ -559,6 +562,44 @@ QMenu *VLCMenuBar::InterfacesMenu( intf_thread_t *p_intf, QMenu *current )
 }
 
 /**
+ * Interface Sub-Menu, Media Enhancement Data interface options
+ **/
+QMenu *VLCMenuBar::MedMenu( intf_thread_t *p_intf, MainInterface *mi, QMenu *current )
+{
+    char *p_medView;
+    p_medView = var_GetString( p_intf, "med-view" );
+    if( p_medView == NULL )
+    {
+        vlc_value_t val, text;
+        var_Create( p_intf, "med-view", VLC_VAR_STRING |
+                    VLC_VAR_HASCHOICE | VLC_VAR_ISCOMMAND );
+        text.psz_string = _("MED interface");
+        var_Change( p_intf, "med-view", VLC_VAR_SETTEXT, &text, NULL );
+
+        val.psz_string = (char *)"showIfDetected";
+        text.psz_string = (char *)_("Show only when MED file exists");
+        var_Change( p_intf, "med-view", VLC_VAR_ADDCHOICE, &val, &text );
+        val.psz_string = (char *)"show";
+        text.psz_string = (char *)_("Always Show");
+        var_Change( p_intf, "med-view", VLC_VAR_ADDCHOICE, &val, &text );
+        val.psz_string = (char *)"hide";
+        text.psz_string = (char *)_("Always Hide");
+        var_Change( p_intf, "med-view", VLC_VAR_ADDCHOICE, &val, &text );
+
+        val.psz_string = (char *) qtu( mi->getMedControlsSetting() );
+        if ( val.psz_string ) 
+            var_Set( p_intf, "med-view", val );
+    }
+
+    QVector<vlc_object_t *> objects;
+    QVector<const char *> varnames;
+    varnames.append( "med-view" );
+    objects.append( VLC_OBJECT(p_intf) );
+
+    return Populate( p_intf, current, varnames, objects );
+}
+
+/**
  * Extensions menu: populate the current menu with extensions
  **/
 void VLCMenuBar::ExtensionsMenu( intf_thread_t *p_intf, QMenu *extMenu )
diff --git a/modules/gui/qt4/menus.hpp b/modules/gui/qt4/menus.hpp
index 3b39c7b..f5e40e6 100644
--- a/modules/gui/qt4/menus.hpp
+++ b/modules/gui/qt4/menus.hpp
@@ -110,6 +110,7 @@ private:
     static QMenu *ViewMenu( intf_thread_t *, QMenu *, MainInterface * mi = NULL );
 
     static QMenu *InterfacesMenu( intf_thread_t *p_intf, QMenu * );
+    static QMenu *MedMenu( intf_thread_t *p_intf, MainInterface *mi, QMenu * );
     static void ExtensionsMenu( intf_thread_t *p_intf, QMenu * );
 
     static QMenu *NavigMenu( intf_thread_t *, QMenu * );
diff --git a/src/libvlc-module.c b/src/libvlc-module.c
index 85637bd..70c5006 100644
--- a/src/libvlc-module.c
+++ b/src/libvlc-module.c
@@ -1012,6 +1012,15 @@ static const char *const ppsz_prefres[] = {
     "You can select which VoD server module you want to use. Set this " \
     "to `vod_rtsp' to switch back to the old, legacy module." )
 
+#define MED_MODULE_TEXT N_("Media Enhancement Data module (.med)")
+#define MED_MODULE_LONGTEXT N_( \
+    "You can disable or enable the MED module from here. This module " \
+    "allows enhanced browsing (layers, events, annotations) using .med files." )
+
+static const int pi_med_values[] = { 1, 0 };
+static const char *const ppsz_med_descriptions[] =
+{ N_("Enable"), N_("Disable") };
+
 #define RT_PRIORITY_TEXT N_("Allow real-time priority")
 #define RT_PRIORITY_LONGTEXT N_( \
     "Running VLC in real-time priority will allow for much more precise " \
@@ -1967,6 +1976,10 @@ vlc_module_begin ()
     add_module( "vod-server", "vod server", NULL, VOD_SERVER_TEXT,
                 VOD_SERVER_LONGTEXT, true )
 
+    add_integer( "MED_Enable", 1, MED_MODULE_TEXT,
+                MED_MODULE_LONGTEXT, true )
+        change_integer_list( pi_med_values, ppsz_med_descriptions ); 
+
     set_section( N_("Plugins" ), NULL )
     add_bool( "plugins-cache", true, PLUGINS_CACHE_TEXT,
               PLUGINS_CACHE_LONGTEXT, true )
-- 
1.8.4.msysgit.0

